@@ -21,7 +21,7 @@
 #include <config.h>
 #include <glib-object.h>
 
-#include <libanjuta/anjuta-plugin.h>
+#include <libanjuta/libanjuta.h>
 #include <libanjuta/interfaces/ianjuta-message-manager.h>
 
 void beaver_util_message_view_buffer_flushed_cb (IAnjutaMessageView *view, 
@@ -29,4 +29,14 @@ void beaver_util_message_view_buffer_flushed_cb (IAnjutaMessageView *view,
 gchar **beaver_util_strv_concat (gchar **strv_1, gchar **strv_2);
 gchar **beaver_util_strv_joinv (gchar **strv_1, ...);
 
+#ifdef ANJUTA_CHECK_VERSION
+#if LIBANJUTA_MAJOR_VERSION >= 2 && LIBANJUTA_MINOR_VERSION >= 23
+#if LIBANJUTA_MINOR_VERSION >= 28
+#define ANJUTA_2_28_OR_HIGHER
+#else
+#define ANJUTA_2_23_TO_26
+#endif
+#endif
+#endif
+
 #endif /* _BEAVER_UTIL */
