@@ -439,6 +439,13 @@ deploy_do_delete (AnjutaPluginSdk *sp)
 
   if (sp->deploy_path)
   {
+    if (!gnome_vfs_init())
+    {
+      g_warning("Error while initing gnome vfs!\n");
+      deploy_set_state (sp, DEPLOY_STATE_ERROR);
+      return;
+    }
+
     uri = gnome_vfs_uri_new (sp->deploy_path);
 
     list = g_list_append (list, uri);
@@ -692,6 +699,7 @@ do_local_gdb (AnjutaPluginSdk *sp)
 {
   gchar *script_name = NULL;
   gint fd = 0;
+  gint child_pid;
   gchar *script_contents = NULL;
   GIOChannel *channel = NULL;
   GIOStatus status;
@@ -753,9 +761,16 @@ do_local_gdb (AnjutaPluginSdk *sp)
   cmd = g_strdup_printf (LOCAL_GDB_COMMAND, sp->triplet, 
       script_name, sp->gdb_local_path);
   cur_dir = g_get_current_dir ();
-  ianjuta_terminal_execute_command (terminal, cur_dir, cmd, NULL, &error);
-
-  if (error != NULL)
+  child_pid = ianjuta_terminal_execute_command (terminal, cur_dir, cmd,
+      NULL, &error);
+  /* Currently child_pid < 0 indicate that the command execution fails, error
+   * data is not filled properly. error handling code is not removed since
+   * in future this error structure might be filled. Keep for forward
+   * compatibility
+   */
+  if (child_pid < 0)
+    g_warning("Error happned while launching local gdb command\n");
+  else if (error != NULL)
   {
     g_warning ("Error whilst launching local gdb command: %s", error->message);
     g_clear_error (&error);
